#ifndef conectiva_h
#define conectiva_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_conectiva: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_conectiva */
public:
	MODULE_conectiva (void);
	int dohtml (const char *key);
	int execmain (int argc, char *argv[], bool);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_conectiva */
};

class HOSTS;
class HOSTINFO;
class VIEWITEMS;
class ROUTES;
class PPPONE;
class USER;
class SHADOW;
class SERVICES;

extern const char scripts_path[];

#include "conectiva.p"

#endif
